@@ -377,4 +377,4 @@ INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE ac
 INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno = '451541'),0.21,'BE ... ... ...');
 INSERT INTO tax (chart_id,rate,taxnumber) VALUES ((SELECT id FROM chart WHERE accno = '640700'),0.21,'BE ... ... ...');
 
-UPDATE defaults SET inventory_accno_id = (SELECT id FROM chart WHERE accno = '340'), income_accno_id = (SELECT id FROM chart WHERE accno = '499000'), expense_accno_id = (SELECT id FROM chart WHERE accno = '499000'), fxgain_accno_id = (SELECT id FROM chart WHERE accno = '755000'), fxloss_accno_id = (SELECT id FROM chart WHERE accno = '655000'), yearend = '12/31', weightunit = 'kg', curr = 'EUR:USD';
+UPDATE defaults SET inventory_accno_id = (SELECT id FROM chart WHERE accno = '340'), income_accno_id = (SELECT id FROM chart WHERE accno = '499000'), expense_accno_id = (SELECT id FROM chart WHERE accno = '499000'), fxgain_accno_id = (SELECT id FROM chart WHERE accno = '755000'), fxloss_accno_id = (SELECT id FROM chart WHERE accno = '655000'), weightunit = 'kg', curr = 'EUR:USD';
