@@ -1,9 +1,5 @@
--- DATEV-SKR03 - Kontenrahmen
--- Mon, 10 Feb 2003
--- Yvonne Einberger
-
-
--- Jetzt beginnt der Kontenrahmen !
+-- DATEV SKR03
+--
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0002700','EDV-Software','A','A','','0002700');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0010000','Fabrikbauten','A','A','','0010000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0011000','Garagen','A','A','','0011000');
@@ -13,13 +9,16 @@ INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0016500','Geschftsbauten','A','A','','0016500');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0008500','Grundstckswert eige.bebau.Grundst.','A','A','','0008500');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0009000','Geschftsbauten','A','A','','0009000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0016000','Bauten auf fremden Grundstcken','H','A','','0016000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0017000','Fabrikbauten','A','A','','0017000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0017500','Garagen','A','A','','0017500');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0017600','Auenanlage','A','A','','0017600');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0020000','Techn.Anlagen und Maschinen','H','A','','0020000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0021000','Maschinen','A','A','','0021000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0022000','Maschinengebundene Werkzeuge','A','A','','0022000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0024000','Maschinelle Anlagen','A','A','','0024000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0028000','Betriebsvorrichtung','A','A','','0028000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0030000','Andere Anlagen,Betrieb-und Geschftsaus','H','A','','0030000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0031000','Andere Anlagen','A','A','','0031000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0032000','PKW','A','A','','0032000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0035000','LKW','A','A','','0035000');
@@ -27,6 +26,7 @@ INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0041000','Geschftsausstattung','A','A','','0041000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0042000','Broeinrichtung','A','A','','0042000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0043000','Ladeneinrichtung','A','A','','0043000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0048000','Geringwertige Wirtschaftsg.b.410EUR','A','A','','0048000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0049000','Sons.Betriebs- Geschftsausstattung','A','A','','0049000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0050400','Ant.a.herr.o.m.Mehrh.bet.Ges.schaft','A','A','','0050400');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0051300','Typisch stille Beteiligungen','A','A','','0051300');
@@ -36,19 +36,35 @@ INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0065000','- Restlaufzeit grer als 5 Jahre','A','L','','0065000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0099600','Pauschalwertb.m.Restlaufzeit v. 1J.','A','A','','0099600');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0140000','Ford. a.Lieferungen und Leistungen','A','A','AR','0140000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0080000','Gezeichnetes Kapital','A','Q','','0080000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0150000','Sonstige Vermgensgegenstnde','A','A','','0150000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0153000','Forderungen gegen Personal','A','A','','0153000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0154500','Umsatzsteuerforderungen','A','A','','0154500');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0100000','Kasse','A','A','AR_paid:AP_paid','0100000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0120000','Bank','A','A','AR_paid:AP_paid','0120000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0096300','Krperschaftssteuerrckstellung','A','Q','','0096300');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0095500','Steuerrckstellung','A','Q','','0095500');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0095700','Gewerbesteuerrckstellung','A','Q','','0095700');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0080100','Ausst.Einl.a.d.gezeichnete Kapital','A','Q','','0080100');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0084000','Kapitalrcklage','A','Q','','0084000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0086000','Gewinnvortrag vor Verwendung','A','Q','','0086000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0086900','Vortrag auf neue Rechnungen','A','Q','','0086900');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0000500','Sachanlagen','H','A','','0000500');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0050000','Finanzanlagen','H','A','','0050000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0051000','Beteiligungen','A','A','','0051000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0063000','Verbindl.gegenber Kreditinstituten','A','L','','0063000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0060000','Verbindlichkeiten','H','L','','0060000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0086800','Verlustvortrag vor Verwendung','A','L','','0086800');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0097000','Sonstige Rckstellungen','A','L','','0097000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0097400','Rckstellungen fr Gewhrleistungen','A','L','','0097400');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0097700','Rcks.f.Abschlu-u.Prfungskosten','A','L','','0097700');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0097800','Aufwandsrckstellungen','A','L','','0097800');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0098000','Aktive Rechnungsabgrenzung','A','A','','0098000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0099000','Passive Rechnungsabgrenzung','A','L','','0099000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0099200','Wertberichtigungen','A','A','','0099200');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0099800','Einzelwertber.m.Restlaufzeit v.1 J.','A','A','','0099800');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0146000','Zweifelhafte Forderungen','A','A','','0146000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0151000','Geleistete Anzahlung auf Vorrte','A','A','','0151000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0151100','Geleistete Anzahlungen 7%','A','A','','0151100');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0151700','Geleistete Anzahlung 16%','A','A','','0151700');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0152500','Kautionen','A','A','','0152500');
@@ -56,12 +72,14 @@ INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0157000','Abziehbare Vorsteuer','A','A','AR_tax:AP_tax','0157000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0160000','Verbindlichkeiten aus Lief.u.Leist.','A','L','AP','0160000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0174100','Verbindl.a.Lohn-und Kirchensteuer','A','L','','0174100');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0178000','Umsatzsteuer-Vorauszahlungen','A','L','','0178000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0178100','Umsatzsteuer-Vorauszahlung 1/11','A','L','','0178100');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0178900','Umsatzsteuer laufendes Jahr','A','L','','0178900');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0179000','Umsatzsteuer Vorjahr','A','L','','0179000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0179100','Umsatzsteuer frhere Jahre','A','L','','0179100');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0180000','Privatentnahme allgemein','A','Q','','0180000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0189000','Privateinlagen','A','Q','','0189000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0210000','Zinsen und hnl.Aufwendungen','A','E','','0210000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0211000','Zinsaufwendung f.kurzf.Verbindlichk','A','E','','0211000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0212000','Zinsaufwendung f.langf.Verbindlichk','A','E','','0212000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0221000','Kapitalertragssteuer','A','E','','0221000');
@@ -73,22 +91,29 @@ INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0250000','Auerordentliche Ertrge','A','I','','0250000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0251000','Betriebsfremde Ertrge n.auerorden','A','I','','0251000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0252000','Periodenfremde Ertrge nicht auero','A','I','','0252000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0270000','Sonstige Ertrge','A','I','','0270000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0272000','Ertr.a.d.Abgang v.Gegens.d.Anlageve','A','I','','0272000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0272500','Ertr.a.d.Abg.v.Gegenst.d.Umlaufverm','A','I','','0272500');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0273000','Ertr.a.Herab.d.Pauschal.z.Forderung','A','I','','0273000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0273100','Ertr.a.Herab.d.Einzelw.z.Forderunge','A','I','','0273100');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0273200','Ertr. aus abgeschriebenen Forderung','A','I','','0273200');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0274200','Versicherungsentschdigungen','A','I','','0274200');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0286000','Gewinnvortrag nach Verwendung','A','L','','0286000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0286800','Verlustvortrag nach Verwendung','A','L','','0286800');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0286900','Vortrag auf neue Rechnungen','A','L','','0286900');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0375000','Erhaltene Boni 7% Vorsteuer','A','I','','0375000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0376000','Erhaltene Boni 16% Vorsteuer','A','I','','0376000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0380000','Anschaffungsnebenkosten','A','E','IC_cogs:IC_expense','0380000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0383000','Leergut','A','E','IC_cogs:IC_expense','0383000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0385000','Zlle und Einfuhrabgaben','A','E','IC_cogs:IC_expense','0385000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0396000','Bestandsver.Roh-,Hilfs-.Betriebs.','A','E','','0396000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0397000','Bestand Roh-,Hilfs-,u.Betriebsstoff','A','A','IC','0397000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0398000','Bestand Waren','A','E','IC','0398000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0399000','Verrechnete Stoffkosten','A','E','IC_cogs:IC_expense','0399000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0400000','Material-und Stoffverbrauch','A','E','IC_cogs:IC_expense','0400000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0410000','Lhne und Gehlter','A','E','AP_amount','0410000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0412500','Ehegattengehalt','A','E','AP_amount','0412500');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0340000','Wareneingang 16% Vorsteuer','A','E','AP_amount','0340000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0342000','Innergemein.Erwerb 7% VorSt u. Ust','A','E','AP_amount','0342000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0342500','Innergem.Erwerb 16% VorSt u. Ust','A','E','AP_amount','0342500');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0373100','Erhaltene Skonti 7% Vorsteuer','A','I','AP_paid','0373100');
@@ -112,7 +137,13 @@ INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0426000','Instandhaltung betrieb.Rume','A','E','AP_amount','0426000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0428000','Sonstige Raumkosten','A','E','AP_amount','0428000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0432000','Gewerbesteuer','A','E','AP_amount','0432000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0434000','Sonstige Betriebssteuern','A','E','','0434000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0436000','Versicherungen','A','E','','0436000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0438000','Beitrge','A','E','','0438000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0439000','Sonstige Abgaben','A','E','AP_amount','0439000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0450000','Fahrzugkosten','A','E','','0450000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0451000','Kfz-Steuer','A','E','','0451000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0452000','Kfz-Versicherungen','A','E','','0452000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0453000','Laufende Kfz-Betriebskosten','A','E','AP_amount','0453000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0454000','Kfz-Reparaturen','A','E','AP_amount','0454000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0455000','Garagenmiete','A','E','AP_amount','0455000');
@@ -160,6 +191,7 @@ INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0498000','Betriebsbedarf','A','E','AP_amount','0498000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0498500','Werkzeuge und Kleingerte','A','E','AP_amount','0498500');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0498600','Sonstige Aufwendungen (Ausbuchung)','A','E','AP_amount','0498600');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0700000','Unfertige Erzeu.unfert.Leistungen','A','A','','0700000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0136000','Geldtransit','A','A','','0136000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0705000','Unfertige Erzeugnisse','A','A','IC','0705000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0708000','Unfertige Leistungen','A','A','IC','0708000');
@@ -172,91 +204,24 @@ INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0882000','Erlse aus Anlageverkufen 16%Ust','A','I','IC_sale','0882000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0895500','Umsatzsteuervergtungen','A','I','','0895500');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0890500','Entnahme v. Gegenst.o.USt.','A','I','','0890500');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0900000','Saldenvertrge,Sachkonten','A','A','','0900000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0900800','Saldenvertrge,Debitoren','A','A','','0900800');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0900900','Saldenvertrge,Kreditoren','A','L','','0900900');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0266000','Ertrge aus Kursdifferenzen','A','I','','0266000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0215000','Aufwendungen aus Kursdifferenzen','A','E','','0215000');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0850000','Provisionserlse','A','I','AR_amount:IC_income','0850000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0830000','Erlse 7%USt','A','I','AR_amount:IC_sale:IC_income','0830000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0840000','Erlse 16% USt.','A','I','AR_amount:IC_sale:IC_income','0840000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0157100','Abziebare Vorsteuer 7%','A','A','AP_tax:CT_tax','0157100');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0157500','Abziehbare Vorsteuer 16%','A','A','AP_tax:AP_paid:CT_tax','0157500');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0177100','Umsatzsteuer 7%','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','0177100');
 INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0177500','Umsatzsteuer 16%','A','L','AR_tax:IC_taxpart:IC_taxservice:CT_tax','0177500');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0178000','Umsatzsteuer-Vorauszahlungen','A','L','AP_amount','0178000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0157100','Abziebare Vorsteuer 7%','A','A','AP_tax:IC_taxpart:IC_taxservice:CT_tax','0157100');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0398000','Bestand Waren','A','A','IC','0398000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0340000','Wareneingang 16% Vorsteuer','A','E','AP_amount:IC_cogs','0340000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0383000','Leergut','A','E','IC_cogs','0383000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0492700','Internetkosten','A','E','AP_amount:IC_expense','0492700');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0451000','Kfz-Steuer','A','E','AP_amount','0451000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0452000','Kfz-Versicherungen','A','E','AP_amount','0452000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0492100','Telefon D1 Handy','A','E','AP_amount:IC_expense','0492000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0157500','Abziehbare Vorsteuer 16%','A','A','AP_tax:IC_taxpart:IC_taxservice:CT_tax','0157500');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0900000','Saldenvortrge,Sachkonten','A','L','','0900000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0286000','Gewinnvortrag nach Verwendung','A','L','','0286000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0320000','Wareneingang o.Steuer','A','E','AP_amount','0320000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0084000','Kapitalrcklage','A','Q','','0084000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0086000','Gewinnvortrag vor Verwendung','A','Q','','0086000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0086800','Verlustvortrag vor Verwendung','A','L','','0086800');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0086900','Vortrag auf neue Rechnungen','A','Q','','0086900');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0081000','Ausstehende Einlagen a.d.gez.Kapital eingefordert','A','A','','0081000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0080100','Ausst.Einl.a.d.gezeichnete Kapital n.eingef.','A','A','','0080100');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0093000','Sonderposten mit Rcklagenanteil steuerf.Rckl.','A','L','','0093000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0095000','Rckstellungen f.Pensionen u.hnl.Verpflichtungen','A','Q','','0095000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0098300','Abgrenzung aktive latente Steuern','A','A','','0098300');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0098600','Damnum/Disagio','A','A','','0098600');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0099200','Wertberichtigungen','A','A','','0099200');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0016000','Bauten auf fremden Grundstcken','A','A','','0016000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0020000','Techn.Anlagen und Maschinen','A','A','','0020000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0030000','Andere Anlagen,Betrieb-und Geschftsaus','A','A','','0030000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0050000','Finanzanlagen','A','A','','0050000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0060000','Verbindlichkeiten','A','L','','0060000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0080000','Gezeichnetes Kapital','A','Q','','0080000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0095500','Steuerrckstellung','A','Q','','0095500');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0098000','Aktive Rechnungsabgrenzung','A','A','','0098000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0099000','Passive Rechnungsabgrenzung','A','L','','0099000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0134500','Eigene Anteile','A','A','','0134500');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0134800','Sonstige Wertpapiere','A','A','','0134800');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0150000','Sonstige Vermgensgegenstnde','A','A','','0150000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0151000','Geleistete Anzahlung auf Vorrte','A','A','','0151000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0159400','Forderungen geg. verb. Unternehmen','A','A','','0159400');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0171000','Erhaltene Anzahlungen-Verbindlichke','A','L','','0171000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0175500','Lohn-und Gehaltsverrechnung','A','L','','0175500');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0210000','Zinsen und hnl.Aufwendungen','A','E','','0210000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0230000','Sonstige Aufwendungen','A','E','','0230000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0240000','Forderungsverlust-bliche Hhe','A','E','','0240000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0260000','Ertrge aus Beteiligten','A','I','','0260000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0262000','Ertrge a.and.Wertpap.u.Ausl.des FinanzAV','A','I','','0262000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0265000','Sonstige Zinsen und hnliche Ertrg','A','I','','0265000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0270000','Sonstige Ertrge','A','I','','0270000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0310000','Fremdleistungen','A','E','','0310000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0421000','Miete','A','E','AP_amount','0421000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0048000','Geringwertige WG bis 410EUR','A','A','AP_amount','0048000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0097700','Rckstellung.f.Abschlu-u.Prfungskosten','A','L','','0097700');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0087000','Festkapital','A','Q','','0087000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0088000','Variables Kapital','A','Q','','0088000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0093100','Sonderpost.m.Rcklageanteil nach 6bEStG','A','Q','','0093100');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0093200','Sonderpost.m.Rcklageanteil n.35 EStR','A','Q','','0093200');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0130000','Wechsel a. Lieferungen u.Leistungen','A','A','','0130000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0131000','Besitzwechsel geg.verb.Unternehmen','A','A','','0131000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0132000','Besitzw.geg.Untern.m.Beteiligungsve','A','A','','0132000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0132700','Finanzwechsel','A','A','','0132700');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0133000','Schecks ','A','A','','0133000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0134000','Anteile verb.Untern.-Umlaufvermgen','A','A','','0134000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0272500','Ertrge a.d.Abgang.v.Geg.d.UV','A','I','','0272500');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0272000','Ertrge a.d.Abgang v.Geg.d.AV','A','I','','0272000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0434000','Sonstige Betriebssteuern','A','E','AP_amount','0434000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0436000','Versicherungen','A','E','AP_amount','0436000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0438000','Beitrge','A','E','AP_amount','0438000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0450000','Fahrzugkosten','A','E','AP_amount','0450000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0700000','Unfertige Erzeugnisse unfert.Leistungen','A','A','','0700000');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0900800','Saldenvortrge,Debitoren','A','L','','0900800');
-INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0900900','Saldenvortrge,Kreditoren','A','L','','0900900');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0830000','Erlse 7%USt','A','I','AR_amount:IC_sale:IC_income','0830000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('0840000','Erlse 16% USt.','A','I','AR_amount:IC_sale:IC_income','0840000');
+INSERT INTO chart (accno,description,charttype,category,link,gifi_accno) VALUES ('950','Rckstellungen','H','L','','');
 --
--- Taxes
---
-update defaults set inventory_accno_id = (select id from chart where accno = '0397000'), income_accno_id = (select id from chart where accno = '0840000'), expense_accno_id = (select id from chart where accno = '0400000'), fxgain_accno_id = (select id from chart where accno = '0266000'), fxloss_accno_id = (select id from chart where accno = '0215000'), invnumber = '1000', sonumber = '1000', ponumber = '1000', curr = 'EUR:USD', weightunit = 'kg';
+update defaults set inventory_accno_id = (select id from chart where accno = '0398000'), income_accno_id = (select id from chart where accno = '0840000'), expense_accno_id = (select id from chart where accno = '0399000'), fxgain_accno_id = (select id from chart where accno = '0266000'), fxloss_accno_id = (select id from chart where accno = '0215000'), curr = 'EUR:USD', weightunit = 'kg';
 --
 INSERT INTO tax (chart_id,rate) VALUES ((SELECT id FROM chart WHERE accno = '0157100'),0.07);
 INSERT INTO tax (chart_id,rate) VALUES ((SELECT id FROM chart WHERE accno = '0157500'),0.16);
 INSERT INTO tax (chart_id,rate) VALUES ((SELECT id FROM chart WHERE accno = '0177100'),0.07);
 INSERT INTO tax (chart_id,rate) VALUES ((SELECT id FROM chart WHERE accno = '0177500'),0.16);
 
-
