@@ -255,23 +255,6 @@ INSERT INTO tax (chart_id, rate) VALUES ((SELECT id FROM chart WHERE accno = '22
 INSERT INTO tax (chart_id, rate) VALUES ((SELECT id FROM chart WHERE accno = '226002'), 0.1);
 INSERT INTO tax (chart_id, rate) VALUES ((SELECT id FROM chart WHERE accno = '226004'), 0.2);
 
--- Cliente di prova
-INSERT INTO public.customer (name,addr1,addr2,addr3,addr4,contact,phone,fax,email,notes,discount,taxincluded,creditlimit,terms,customernumber,cc,bcc) VALUES ('cliente di prova','','','','','','','','','Cliente di prova da usare per comprendere il funzionamento della procedura.','0','0','0','30','1','','');
-INSERT INTO public.customertax (customer_id,chart_id) VALUES ((select id from customer where customernumber = '1'), (select id from chart where accno = '226004'));
-
--- Fornitore di prova
-INSERT INTO public.vendor (name,addr1,addr2,addr3,addr4,contact,phone,fax,email,notes,terms,taxincluded,vendornumber,cc,bcc) VALUES ('fornitore di prova','','','','','','','','','Fornitore per fare qualche prova.','30','0','1','','');
-INSERT INTO public.vendortax (vendor_id,chart_id) VALUES ((select id from vendor where vendornumber = '1'), (select id from chart where accno = '112004'));
-
--- Articolo di prova nel magazzino
-INSERT INTO public.parts (partnumber,description,unit,listprice,sellprice,lastcost,priceupdate,weight,onhand,notes,makemodel,assembly,alternate,rop,inventory_accno_id,income_accno_id,expense_accno_id,bin,obsolete,bom,image,drawing,microfiche,partsgroup_id) VALUES ('1','articolo di prova','pz','10','20','0','28/09/2003','0','0','Articolo da usare per fare qualche prova','0','0','0','0', (select id from chart where accno = '105001'), (select id from chart where accno = '541001'), (select id from chart where accno = '645001'),'','0','0','','','','0');
-INSERT INTO public.partstax (parts_id,chart_id) VALUES ((select id from parts where partnumber = '1'), (select id from chart where accno = '112001'));
-INSERT INTO public.partstax (parts_id,chart_id) VALUES ((select id from parts where partnumber = '1'), (select id from chart where accno = '112002'));
-INSERT INTO public.partstax (parts_id,chart_id) VALUES ((select id from parts where partnumber = '1'), (select id from chart where accno = '112004'));
-INSERT INTO public.partstax (parts_id,chart_id) VALUES ((select id from parts where partnumber = '1'), (select id from chart where accno = '226001'));
-INSERT INTO public.partstax (parts_id,chart_id) VALUES ((select id from parts where partnumber = '1'), (select id from chart where accno = '226002'));
-INSERT INTO public.partstax (parts_id,chart_id) VALUES ((select id from parts where partnumber = '1'), (select id from chart where accno = '226004'));
-
 --
 -- update defaults
 --
@@ -281,9 +264,6 @@ UPDATE DEFAULTS SET income_accno_id = (select id from chart where accno = '54100
 UPDATE DEFAULTS SET expense_accno_id = (select id from chart where accno = '645001');
 UPDATE DEFAULTS SET fxgain_accno_id = (select id from chart where accno = '756011');
 UPDATE DEFAULTS SET fxloss_accno_id = (select id from chart where accno = '655011');
-UPDATE DEFAULTS SET invnumber = '200310000';
-UPDATE DEFAULTS SET sonumber = '200320000';
-UPDATE DEFAULTS SET ponumber = '200330000';
 UPDATE DEFAULTS SET curr = 'EUR';
 UPDATE DEFAULTS SET weightunit = 'kg';
 
