@@ -1,48 +1,59 @@
 -- Default chart of accounts
+-- charset: ISO-8859-1
+--   http://www.nif.idrett.no/ftp/Lover/doc/kontoplan.htm
+--   http://www.legemiddelverket.no/rundskriv/frahtil/1999/ik-1499.htm
 -- sample only
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('100', 'Immaterielle eiendeler', 'H', '', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('10', 'Immaterielle eiendeler', 'H', '', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1000', 'Forskning og utvikling', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1030', 'Patenter', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1040', 'Lisenser', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1050', 'Varemerker', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1060', 'Andre rettigheter', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1070', 'Utsatt skattefordel', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('110', 'Varige driftsmidler', 'H', '', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1100', 'Bygninger', 'A','', 'A', 'AR_paid');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1120', 'Bygningsmessige anlegg', 'A','', 'A', 'AR_paid');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1080', 'Goodwill', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('11', 'Varige driftsmidler', 'H', '', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1100', 'Bygninger', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1120', 'Bygningsmessige anlegg', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1140', 'Jord- og skogbrukseiendommer', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1150', 'Tomter og andre grunnarealer', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1200', 'Maskiner og anlegg', 'A','', 'A', 'AR_paid');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1210', 'Maskiner og anlegg under utfrelse', 'A','', 'A', 'AR_paid');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('12', 'Transportmidler, inventar, maskiner o.l.', 'H', '', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1200', 'Maskiner og anlegg', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1210', 'Maskiner og anlegg under utfrelse', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1230', 'Biler', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1240', 'Andre transportmidler', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1250', 'Inventar', 'A','', 'A', 'IC');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1260', 'Fast bygningsinventar med annen avskrivning', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1270', 'Verkty mv.', 'A','', 'A', 'IC');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1280', 'Kontormaskiner', 'A','', 'A', 'AR');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('135', 'Finansielle anleggsmidler', 'H', '', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1270', 'Verkty mv.', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1280', 'Kontormaskiner', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('13', 'Finansielle anleggsmidler', 'H', '', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1300', 'Investeringer i datterselskaper', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1350', 'Investeringer i aksjer og andeler', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1360', 'Obligasjoner', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1370', 'Fordringer p eiere, styremedlemmer mv.', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1380', 'Fordringer p ansatte', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1390', 'Andre fordringer', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('140', 'Varer', 'H', '', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1400', 'Rvarer og innkjpte halvfabrikata', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1420', 'Varer under tilvirkning', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1440', 'Ferdige egentilvirkede varer', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1460', 'Innkjpte varer for videresalg', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link)
+values ('1390', 'Andre langsiktige fordringer', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link)
+values ('14', 'Varer', 'H', '', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1400', 'Rvarer og innkjpte halvfabrikata', 'A','', 'A', 'IC');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1420', 'Varer under tilvirkning', 'A','', 'A', 'IC');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1440', 'Ferdige egentilvirkede varer', 'A','', 'A', 'IC');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1460', 'Innkjpte varer for videresalg', 'A','', 'A', 'IC');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1480', 'Forskuddsbetaling til leverandrer', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('151', 'Fordringer', 'H', '', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1510', 'Kundefordringer', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('15', 'Fordringer', 'H', '', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1500', 'Kundefordringer', 'A','', 'A', 'AR');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1520', 'Andre kortsiktige fordringer', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1530', 'Opptjente ikke fakturerte driftsinntekter', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1530', 'Opptjente, ikke fakturerte driftsinntekter', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1570', 'Andre kortsiktige fordringer', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1580', 'Avsetning tap p fordringer', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1700', 'Forskuddsbetalte leier', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1710', 'Forskuddsbetalte renter', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1750', 'Plpte leier', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1760', 'Plpte renter', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('17', 'Andre fordringer', 'H', '', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1700', 'Forskuddsbetalt leie', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1710', 'Forskuddsbetalt rente', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1720', 'Forskuddsbetalt lnn', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1750', 'Plpte leieinntekter', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1760', 'Plpte renteinntekter', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1780', 'Krav p innbetaling av selskapskapital', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('180', 'Investeringer', 'H', '', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('18', 'Investeringer', 'H', '', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1800', 'Aksjer & andeler i foretak i samme kons.', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1810', 'Markesdbaserte aksjer', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1820', 'Andre aksjer', 'A','', 'A', '');
@@ -51,11 +62,12 @@ insert into chart (accno,description,charttype,gifi_accno,category,link) values
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1850', 'Markedsbaserte sertifikater', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1860', 'Andre sertifikater', 'A','', 'A', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1880', 'Andre finansielle instrumenter', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('191', 'Bankinnskudd, kontanter o.l.', 'H', '', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1910', 'Kasse', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1930', 'Bankinnskudd', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1940', 'Bankinnskudd for skattetrekk', 'A','', 'A', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1970', 'Postgiro', 'A','', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('19', 'Bankinnskudd, kontanter o.l.', 'H', '', 'A', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1900', 'Kontanter', 'A','', 'A', 'AR_paid:AP_paid');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1910', 'Kasse', 'A','', 'A', 'AR_paid:AP_paid');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1920', 'Bankinnskudd', 'A','', 'A', 'AR_paid:AP_paid');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('1950', 'Bankinnskudd for skattetrekk', 'A','', 'A', 'AR_paid:AP_paid');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('20', 'Egenkapital', 'H', '', 'Q', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('200', 'Innskutt egenkapital', 'H', '', 'Q', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2000', 'Aksjekapital', 'A','', 'Q', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2010', 'Egne aksjer', 'A','', 'Q', '');
@@ -83,21 +95,21 @@ insert into chart (accno,description,charttype,gifi_accno,category,link) values
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2340', 'Andre valutaln', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2360', 'Byggeln', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2380', 'Kassakreditt', 'A','', 'L', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2410', 'Leverandrgjeld', 'A','', 'L', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2500', 'Betalbar skatt, ikke utlignet', 'A','', 'L', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2510', 'Betalbar skatt, utlignet', 'A','', 'L', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2610', 'Skattetrekk', 'A','', 'L', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2400', 'Leverandrgjeld', 'A','', 'L', 'AP');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2500', 'Avsatt betalbar skatt', 'A','', 'L', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2510', 'Skattebetaling', 'A','', 'L', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2600', 'Skattetrekk', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2620', 'Pleggstrekk', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2630', 'Bidragstrekk', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2640', 'Trygdetrekk', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2650', 'Forsikringstrekk', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2660', 'Fagforeningstrekk', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2690', 'Andre trekk', 'A','', 'L', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2710', 'Utgende 24% mva', 'A','', 'L', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2715', 'Utgende 12% mva', 'A','', 'L', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2710', 'Utgende 24% mva', 'A','', 'L', 'AR_tax:IC_taxpart:IC_taxservice:CT_tax');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2715', 'Utgende 12% mva', 'A','', 'L', 'AR_tax:IC_taxpart:IC_taxservice:CT_tax');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2717', 'Beregnet avgift utlandet', 'A','', 'L', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2720', 'Inngende 24% mva', 'A','', 'L', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2725', 'Inngende 12% mva', 'A','', 'L', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2720', 'Inngende 24% mva', 'A','', 'L', 'AP_tax:IC_taxpart:IC_taxservice:CT_tax');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2725', 'Inngende 12% mva', 'A','', 'L', 'AP_tax:IC_taxpart:IC_taxservice:CT_tax');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2745', 'Grunnlag 1 tjenester utlandet', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2746', 'Grunnlag 2 tjenester utlandet', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2750', 'Oppgjrskonto merverdiavgift', 'A','', 'L', '');
@@ -111,28 +123,31 @@ insert into chart (accno,description,charttype,gifi_accno,category,link) values
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2930', 'Gjeld til ansatte og aksjonrer', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2950', 'Plpte renter', 'A','', 'L', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('2960', 'Plpte kostn. og forskuddsbet. inskudd', 'A','', 'L', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('301', 'Resultat fr ekstraorinre inntekter og kostnader', 'H', '', 'I', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3010', 'Salgsinntekter, 24% mva', 'A','', 'I', 'AP_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3019', 'Frakt', 'A','', 'I', 'AP_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3020', 'Salgsinntekter, 12% mva', 'A','', 'I', 'AP_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3060', 'Uttak av varer', 'A','', 'I', 'AP_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3080', 'Rabatter og andre salgsinntektsreduksjon', 'A','', 'I', 'AP_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3099', 'Miljavgift', 'A','', 'I', 'AP_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3110', 'Salgsinntekter, avgiftsfrie', 'A','', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3', 'Salgs- og driftsinntekter', 'H', '', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3010', 'Salgsinntekter, 24% mva', 'A','', 'I', 'AR_amount:IC_sale');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3019', 'Frakt', 'A','', 'I', 'IC_income');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3020', 'Salgsinntekter, 12% mva', 'A','', 'I', 'AR_amount:IC_sale');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3060', 'Uttak av varer', 'A','', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3080', 'Rabatter og andre salgsinntektsreduksjon', 'A','', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3099', 'Miljavgift', 'A','', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3110', 'Salgsinntekter, avgiftsfrie', 'A','', 'I', 'AR_amount:IC_sale');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3160', 'Uttak av varer', 'A','', 'I', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3180', 'Rabatter og andre salgsinntektsreduksjon', 'A','', 'I', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3300', 'Spes. offent. avg. tilvirk./solgte varer', 'A','', 'I', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3400', 'Spes. offent. avg. tilvirk./solgte varer', 'A','', 'I', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3440', 'Spes. offentlige tilskudd for tjenester', 'A','', 'I', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3500', 'Garanti og service', 'A','', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3500', 'Uopptjente inntekter garanti', 'A','', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3510', 'Uopptjente inntekter service', 'A','', 'I', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3600', 'Leieinntekter fast eiendom', 'A','', 'I', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3610', 'Leieinntekter andre varige driftsmidler', 'A','', 'I', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3620', 'Andre leieinntekter', 'A','', 'I', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3700', 'Provisjonsinntekter', 'A','', 'I', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3800', 'Gevinst ved avgang av anleggsmidler', 'A','', 'I', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('3900', 'Andre driftsrelaterte inntekter', 'A','', 'I', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4010', 'Innkjp varer, avgiftspliktig 24% mva', 'A','', 'E', 'AR_tax');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4020', 'Innkjp varer, avgiftspliktig 12% mva', 'A','', 'E', 'AR_tax');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4', 'Varekostnad', 'H', '', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('40', 'Rvarer og halvfabrikata', 'H', '', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4010', 'Innkjp varer, avgiftspliktig 24% mva', 'A','', 'E', 'AP_amount:IC_cogs:IC_expense');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4020', 'Innkjp varer, avgiftspliktig 12% mva', 'A','', 'E', 'AP_amount:IC_cogs:IC_expense');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4060', 'Innkjpsprisreduksjoner', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4070', 'Frakt, toll og spedisjon', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4090', 'Beholdningsendring', 'A','', 'E', '');
@@ -141,6 +156,14 @@ insert into chart (accno,description,charttype,gifi_accno,category,link) values
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4170', 'Frakt, toll og spedisjon, avgiftsfritt', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4180', 'Innkjpsprisreduksjoner', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4190', 'Beholdningsendring', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('43', 'Varer for videresalg', 'H', '', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4310', 'Innkjp av varer for videresalg, 24% mva', 'A','', 'E', 'AP_amount:IC_cogs:IC_expense');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4320', 'Innkjp av varer for videresalg, 12% mva', 'A','', 'E', 'AP_amount:IC_cogs:IC_expense');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4360', 'Frakt, toll m.m. vedr. innkjp av varer for videresalg', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4370', 'Rabatter m.m. vedr. innkjp av varer for videresalg', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4380', 'Varekostnad', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('4390', 'Beholdningsendring varer for videresalg', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5', 'Lnnskostnader', 'H', '', 'I', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5010', 'Faste lnninger', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5090', 'Periodiseringskonto lnn', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5190', 'Plpne feriepenger', 'A','', 'E', '');
@@ -166,27 +189,34 @@ insert into chart (accno,description,charttype,gifi_accno,category,link) values
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5930', 'Andre ikke arb.giv.avg.pliktige forsikr.', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5950', 'Personalforsikring', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('5960', 'Gaver til ansatte', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6', 'Andre driftskostnader, av- og nedskrivninger', 'H', '', 'I', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6000', 'Avskrivning p bygn. & annen fast eiend.', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6010', 'Avskrivning p transportmidler, maskiner', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6020', 'Avskrivning p immaterielle eiendeler', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6050', 'Nedskr. varige driftsmidl. & imat. eiend', 'A','', 'E', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6100', 'Frakter, transportkostnader og forsikring', 'A','', 'E', 'IC_expense');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6110', 'Toll og spedisjonskostnader ved forsend', 'A','', 'E', 'IC_expense');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6260', 'Vann', 'A','', 'E', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6300', 'Leie lokaler', 'A','', 'E', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6320', 'Renovasjon, vann, avlp mv.', 'A','', 'E', 'IC_expense');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6340', 'Lys, varme', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6100', 'Frakter, transportkostnader og forsikring', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6110', 'Toll og spedisjonskostnader ved forsend', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('62', 'Energi, brensel o.l. vedr. produksjon', 'H', '', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6200', 'Elektrisitet', 'A','', 'E', 'AP_amount');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6260', 'Vann', 'A','', 'E', 'AP_amount');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('63', 'Kostnader. vedr. lokaler', 'H', '', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6300', 'Leie lokaler', 'A','', 'E', 'AP_amount');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6320', 'Renovasjon, vann, avlp mv.', 'A','', 'E', 'AP_amount');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6340', 'Lys, varme', 'A','', 'E', 'AP_amount');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6360', 'Renhold', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('64', 'Leie av maskiner, inventar o.l.', 'H', '', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6400', 'Leie av driftsmidler', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6430', 'Leie andre kontormaskiner', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6540', 'Inventar', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6550', 'Driftsmaterialer', 'A','', 'E', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6560', 'Rekvisita', 'A','', 'E', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6570', 'Arbeidsklr og verneutstyr', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6560', 'Rekvisita', 'A','', 'E', 'AP_amount');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6570', 'Arbeidsklr og verneutstyr', 'A','', 'E', 'AP_amount');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6600', 'Reparasjoner og vedlikehold bygninger', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6620', 'Reparasjoner og vedlikehold utstyr', 'A','', 'E', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6700', 'Revisjons- og regnskapshonorar', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6700', 'Revisjonshonorar', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6720', 'Honorar for konomisk & juridisk bistand', 'A','', 'E', '');
-insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6800', 'Kontorrekvisita', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6750', 'Honorar regnskapsfrer', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6800', 'Kontorrekvisita', 'A','', 'E', 'AP_amount');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6820', 'Trykksaker', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6840', 'Aviser, tidsskrifter, bker mv.', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('6860', 'Mter, kurs, oppdatering mv.', 'A','', 'E', '');
@@ -207,6 +237,7 @@ insert into chart (accno,description,charttype,gifi_accno,category,link) values
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7320', 'Reklamekostnader', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7350', 'Representasjon, fradragsberettiget', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7360', 'Representasjon, ikke fradragsberettiget', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7400', 'Kontingenter og gaver', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7500', 'Forsikringspremier', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7550', 'Garanti- og servicekostnader', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7600', 'Lisenesavgifter og royalties', 'A','', 'E', '');
@@ -218,8 +249,12 @@ insert into chart (accno,description,charttype,gifi_accno,category,link) values
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7800', 'Tap ved avgang anleggsmidler', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7820', 'Innkommet p tidligere nedskrevne fordri', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7830', 'Tap p fordringer', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7850', 'Tap pga. brannskade', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7860', 'Tap p kontrakter', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7900', 'Beholdningsendring anlegg under utfrels', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('7990', 'Andre driftskostnader', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8', 'Finansinntekter og -kostnader, skatter, m.m.', 'H', '', 'I', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8000', 'Inntekter p investeringer i datterselskap', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8040', 'Renteinntekter, skattefrie', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8050', 'Annen renteinntekt', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8060', 'Purregebyr, kunder', 'A','', 'E', '');
@@ -235,6 +270,7 @@ insert into chart (accno,description,charttype,gifi_accno,category,link) values
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8180', 'Agio tap', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8300', 'Betalbar skatt', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8320', 'Utsatt skatt', 'A','', 'E', '');
+insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8350', 'Skattekostnad', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8600', 'Betalbar skatt', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('8620', 'Utsatt skatt', 'A','', 'E', '');
 insert into chart (accno,description,charttype,gifi_accno,category,link) values ('880', 'Fond for vurderingsforskjeller', 'H', '', 'E', '');
@@ -257,5 +293,5 @@ insert into tax (chart_id,rate) values ((select id from chart where accno = '271
 insert into tax (chart_id,rate) values ((select id from chart where accno = '2720'),0.24);
 insert into tax (chart_id,rate) values ((select id from chart where accno = '2725'),0.12);
 --
-update defaults set inventory_accno_id = (select id from chart where accno = '4010'), income_accno_id = (select id from chart where accno = '3010'), expense_accno_id = (select id from chart where accno = '6560'), fxgain_accno_id = (select id from chart where accno = '8080'), fxloss_accno_id = (select id from chart where accno = '8180'), invnumber = '1000', sonumber = '1000', ponumber = '1000', curr = 'NOK:EUR:USD', weightunit = 'kg';
+update defaults set inventory_accno_id = (select id from chart where accno = '1250'), income_accno_id = (select id from chart where accno = '3010'), expense_accno_id = (select id from chart where accno = '4010'), fxgain_accno_id = (select id from chart where accno = '8080'), fxloss_accno_id = (select id from chart where accno = '8180'), curr = 'NOK:EUR:USD', weightunit = 'kg';
 --
